==> 0.0.6.tar.gz: ios/Classes/SwiftMmComponentPlugin.swift <==
import Flutter
import UIKit


public class SwiftMmComponentPlugin: NSObject, FlutterPlugin, LoginCompDelegate {
    var methodResult: FlutterResult? = nil
    
    
    public func onSuccess(param: NSDictionary) {
        let jsonObject: NSMutableDictionary = NSMutableDictionary()
        
        jsonObject.setValue("onSuccess", forKey: "resultCode")
        jsonObject.setValue(param, forKey: "resultData")
        
        let jsonData: NSData
        
        do {
            jsonData = try JSONSerialization.data(withJSONObject: jsonObject, options: JSONSerialization.WritingOptions()) as NSData
            let jsonString = NSString(data: jsonData as Data, encoding: String.Encoding.utf8.rawValue)! as String
            methodResult?(jsonString)
        } catch _ {
            print ("JSON Failure")
        }
    }
    
    
    public func onFail(param: NSDictionary) {
        let jsonObject: NSMutableDictionary = NSMutableDictionary()
        
        jsonObject.setValue("onFail", forKey: "resultCode")
        jsonObject.setValue(param, forKey: "resultData")
        
        let jsonData: NSData
        
        do {
            jsonData = try JSONSerialization.data(withJSONObject: jsonObject, options: JSONSerialization.WritingOptions()) as NSData
            let jsonString = NSString(data: jsonData as Data, encoding: String.Encoding.utf8.rawValue)! as String
            methodResult?(jsonString)
        } catch _ {
            print ("JSON Failure")
        }
    }
    
    public func goto(param: NSDictionary) {
        let jsonObject: NSMutableDictionary = NSMutableDictionary()
        
        jsonObject.setValue("onGoto", forKey: "resultCode")
        jsonObject.setValue(param, forKey: "resultData")
        
        let jsonData: NSData
        
        do {
            jsonData = try JSONSerialization.data(withJSONObject: jsonObject, options: JSONSerialization.WritingOptions()) as NSData
            let jsonString = NSString(data: jsonData as Data, encoding: String.Encoding.utf8.rawValue)! as String
            methodResult?(jsonString)
        } catch _ {
            print ("JSON Failure")
        }
    }
    
    public func redirect(param: NSDictionary) {
        let jsonObject: NSMutableDictionary = NSMutableDictionary()
        
        jsonObject.setValue("onRedirect", forKey: "resultCode")
        jsonObject.setValue(param, forKey: "resultData")
        
        let jsonData: NSData
        
        do {
            jsonData = try JSONSerialization.data(withJSONObject: jsonObject, options: JSONSerialization.WritingOptions()) as NSData
            let jsonString = NSString(data: jsonData as Data, encoding: String.Encoding.utf8.rawValue)! as String
            methodResult?(jsonString)
        } catch _ {
            print ("JSON Failure")
        }
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "mm_component", binaryMessenger: registrar.messenger())
        let instance = SwiftMmComponentPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if (call.method == "getPlatformVersion") {
            result("iOS " + UIDevice.current.systemVersion)
        }
        else if (call.method == "open") {
          if let args = call.arguments as? Dictionary<String, Any>,
            let operation = args["operation"] as? String,
            let version = args["version"] as? String,
            let url = args["url"] as? String,
            let mode = args["mode"] as? String,
            let failAlertMode = args["failAlertMode"] as? String
          {
            methodResult = result

            if (mode == "NEW") {
                let status = UserDefaults.standard.bool(forKey: "KEY_BIOMETRIC_STATUS")

                        let navigation: LCNavigation = LCNavigation(rawValue: operation) ?? .KEY_NAVIGATION_LOGIN

                        DispatchQueue.main.async(){

                          let login = LoginVC(navigation: navigation)
                            login.delegate = self
                            login.externalURL = url
                            login.appVersion = version
                            login.biometricStatus = status
                            login.failAlertMode = failAlertMode
                            login.modalPresentationStyle = .fullScreen

                            let window = UIApplication.shared.keyWindow
                            let currentVC = window?.rootViewController

                            currentVC?.present(login, animated: true, completion: nil)
                        }
            }

          } else {
            result(FlutterError.init(code: "bad args", message: nil, details: nil))
          }
        }
    }
}

==> 0.0.10.tar.gz: ios/Classes/SwiftMmComponentPlugin.swift <==
import Flutter
import UIKit


public class SwiftMmComponentPlugin: NSObject, FlutterPlugin, LoginCompDelegate {
    var methodResult: FlutterResult? = nil
    
    
    public func onSuccess(param: NSDictionary) {
        returnResponse(param: param, code: "onSuccess")
    }
    
    
    public func onFail(param: NSDictionary) {
        returnResponse(param: param, code: "onFail")
    }
    
    public func goto(param: NSDictionary) {
        returnResponse(param: param, code: "onGoto")
    }
    
    public func redirect(param: NSDictionary) {
        returnResponse(param: param, code: "onRedirect")
    }
    
    public func returnResponse(param: NSDictionary, code: NSString) {
        do {
            let retData = try JSONSerialization.data(withJSONObject: param, options: JSONSerialization.WritingOptions.prettyPrinted) as NSData
            let retString = NSString(data: retData as Data, encoding: String.Encoding.utf8.rawValue)! as String
            
            let jsonObject: NSMutableDictionary = NSMutableDictionary()
            jsonObject.setValue(code, forKey: "resultCode")
            jsonObject.setValue(retString, forKey: "resultData")
            
            let jsonData = try JSONSerialization.data(withJSONObject: jsonObject, options: JSONSerialization.WritingOptions.prettyPrinted) as NSData
            let jsonString = NSString(data: jsonData as Data, encoding: String.Encoding.utf8.rawValue)! as String
            
            methodResult?(jsonString)
        } catch _ {
            print ("JSON Failure")
        }
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "mm_component", binaryMessenger: registrar.messenger())
        let instance = SwiftMmComponentPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if (call.method == "getPlatformVersion") {
            result("iOS " + UIDevice.current.systemVersion)
        }
        else if (call.method == "open") {
          if let args = call.arguments as? Dictionary<String, Any>,
            let operation = args["operation"] as? String,
            let version = args["version"] as? String,
            let url = args["url"] as? String,
            let openNewComponent = args["openNewComponent"] as? Bool,
            let failAlertMode = args["failAlertMode"] as? String
          {
            methodResult = result

            if (openNewComponent) {
                let status = UserDefaults.standard.bool(forKey: "KEY_BIOMETRIC_STATUS")

                        let navigation: LCNavigation = LCNavigation(rawValue: operation) ?? .KEY_NAVIGATION_LOGIN

                        DispatchQueue.main.async(){

                          let login = LoginVC(navigation: navigation)
                            login.delegate = self
                            login.externalURL = url
                            login.appVersion = version
                            login.biometricStatus = status
                            login.failAlertMode = failAlertMode
                            login.modalPresentationStyle = .fullScreen

                            let window = UIApplication.shared.keyWindow
                            let currentVC = window?.rootViewController

                            currentVC?.present(login, animated: true, completion: nil)
                        }
            }

          } else {
            result(FlutterError.init(code: "bad args", message: nil, details: nil))
          }
        }
    }
}
